Index: base/android/base_jni_onload.h |
diff --git a/base/android/base_jni_onload.h b/base/android/base_jni_onload.h |
index dcc7756684eba733881b84f6891fe41f16d25ad6..f3f05fa54ffcb37d6af6e2a48d2b18469b37b94c 100644 |
--- a/base/android/base_jni_onload.h |
+++ b/base/android/base_jni_onload.h |
@@ -9,22 +9,17 @@ |
#include <vector> |
#include "base/base_export.h" |
-#include "base/callback.h" |
namespace base { |
namespace android { |
-// Returns whether JNI registration succeeded. Caller shall put the |
-// RegisterCallback into |callbacks| in reverse order. |
-typedef base::Callback<bool(JNIEnv*)> RegisterCallback; |
-BASE_EXPORT bool OnJNIOnLoadRegisterJNI( |
- JavaVM* vm, |
- std::vector<RegisterCallback> callbacks); |
- |
-// Returns whether initialization succeeded. Caller shall put the |
-// InitCallback into |callbacks| in reverse order. |
-typedef base::Callback<bool(void)> InitCallback; |
-BASE_EXPORT bool OnJNIOnLoadInit(std::vector<InitCallback> callbacks); |
+class JNIOnLoadDelegate; |
+ |
+// Returns whether JNI registration and initialization succeeded. Caller shall |
+// put the JNIOnLoadDelegate into |delegates| in reverse order. Refer |
+// JNIOnLoadDelegate for more information. |
+BASE_EXPORT bool OnJNIOnLoad(JavaVM* vm, |
+ std::vector<JNIOnLoadDelegate*>* delegates); |
} // namespace android |
} // namespace base |